@@ -389,7 +389,7 @@ def migrate_bash_completion(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_bash-completion files"
     is_single_binary = sum(1 for _ in manifest.all_packages) == 1
@@ -483,7 +483,7 @@ def migrate_shell_completions(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_shell_completions files"
     is_single_binary = sum(1 for _ in manifest.all_packages) == 1
@@ -582,7 +582,7 @@ def migrate_dh_installsystemd_files(
     manifest: HighLevelManifest,
     _acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_installsystemd files"
     for dctrl_bin in manifest.all_packages:
@@ -615,7 +615,7 @@ def migrate_maintscript(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_installdeb files"
     mutable_manifest = assume_not_none(manifest.mutable_manifest)
@@ -699,7 +699,6 @@ def migrate_maintscript(
                         f" conffile management definition for same path defined already (in the"
                         f" existing manifest or an migration e.g., inside {mainscript_file})"
                     )
-                feature_migration.already_present += 1
                 continue
 
             package_definition.add_conffile_management(item)
@@ -724,7 +723,7 @@ def migrate_install_file(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_install config files"
     mutable_manifest = assume_not_none(manifest.mutable_manifest)
@@ -915,7 +914,7 @@ def migrate_installdocs_file(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_installdocs config files"
     mutable_manifest = assume_not_none(manifest.mutable_manifest)
@@ -962,7 +961,7 @@ def migrate_installexamples_file(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_installexamples config files"
     mutable_manifest = assume_not_none(manifest.mutable_manifest)
@@ -1016,7 +1015,7 @@ def migrate_installinfo_file(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_installinfo config files"
     mutable_manifest = assume_not_none(manifest.mutable_manifest)
@@ -1091,7 +1090,7 @@ def migrate_installman_file(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_installman config files"
     mutable_manifest = assume_not_none(manifest.mutable_manifest)
@@ -1211,7 +1210,7 @@ def migrate_not_installed_file(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_missing's not-installed config file"
     mutable_manifest = assume_not_none(manifest.mutable_manifest)
@@ -1251,7 +1250,7 @@ def detect_pam_files(
     manifest: HighLevelManifest,
     _acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "detect dh_installpam files (min dh compat)"
     for dctrl_bin in manifest.all_packages:
@@ -1266,7 +1265,7 @@ def migrate_tmpfile(
     manifest: HighLevelManifest,
     _acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_installtmpfiles config files"
     for dctrl_bin in manifest.all_packages:
@@ -1290,7 +1289,7 @@ def migrate_lintian_overrides_files(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_lintian config files"
     for dctrl_bin in manifest.all_packages:
@@ -1314,7 +1313,7 @@ def migrate_links_files(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh_link files"
     mutable_manifest = assume_not_none(manifest.mutable_manifest)
@@ -1370,7 +1369,6 @@ def migrate_links_files(
                         " already (in the existing manifest or an migration e.g., inside"
                         f" {links_file.fs_path})"
                     )
-                feature_migration.already_present += 1
                 continue
             condition = dhe_line.conditional()
             package_definition.add_symlink(
@@ -1388,7 +1386,7 @@ def migrate_misspelled_readme_debian_files(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "misspelled README.Debian files"
     for dctrl_bin in manifest.all_packages:
@@ -1420,7 +1418,7 @@ def migrate_doc_base_files(
     manifest: HighLevelManifest,
     _: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "doc-base files"
     # ignore the dh_make ".EX" file if one should still be present. The dh_installdocs tool ignores it too.
@@ -1471,7 +1469,7 @@ def migrate_dh_hook_targets(
     _: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    migration_target: DebputyIntegrationMode,
+    migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "dh hook targets"
     source_root = os.path.dirname(debian_dir.fs_path)
@@ -1484,6 +1482,7 @@ def migrate_dh_hook_targets(
         ).decode("utf-8")
     )
     sample_hook_target: Optional[str] = None
+    assert migration_target is not None
     replaced_commands = DH_COMMANDS_REPLACED[migration_target]
 
     for hook_target_def in detected_hook_targets["hook-targets"]:
@@ -1523,7 +1522,7 @@ def detect_unsupported_zz_debputy_features(
     manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "Known unsupported features"
 
@@ -1542,7 +1541,7 @@ def detect_obsolete_substvars(
     _manifest: HighLevelManifest,
     _acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = (
         "Check for obsolete ${foo:var} variables in debian/control"
@@ -1625,7 +1624,7 @@ def detect_dh_addons_zz_debputy_rrr(
     _manifest: HighLevelManifest,
     _acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "Check for dh-sequence-addons"
     r = read_dh_addon_sequences(debian_dir)
@@ -1650,7 +1649,7 @@ def detect_dh_addons_with_full_integration(
     _manifest: HighLevelManifest,
     _acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "Check for dh-sequence-addons and Build-Depends"
     feature_migration.warn(
@@ -1669,7 +1668,7 @@ def detect_dh_addons_with_zz_integration(
     _manifest: HighLevelManifest,
     acceptable_migration_issues: AcceptableMigrationIssues,
     feature_migration: FeatureMigration,
-    _migration_target: DebputyIntegrationMode,
+    _migration_target: Optional[DebputyIntegrationMode],
 ) -> None:
     feature_migration.tagline = "Check for dh-sequence-addons"
     r = read_dh_addon_sequences(debian_dir)
